@@ -54,6 +54,9 @@ class Configuration(object):
         'environment': {
 
         },
+        'nginx': {
+            'client_max_body_size': '10m'
+        }
     }
     def load_sites(self, config_file_content=None, env_dict=None):
         """
@@ -255,6 +258,7 @@ class Configuration(object):
             'ssl': env.get('ssl', False),
             'ssl_cert_path': os.path.join(env_dict.get("path"), env_dict.get('ssl_cert_path', None) or ""),
             'ssl_key_path': os.path.join(env_dict.get("path"), env_dict.get('ssl_key_path', None) or ""),
+            'bind_ip': env_dict.get('bind_ip', '*'),
 
             'home': '/home/%s' %  env_dict.get("user"),
         }
